<div align="center">

# linecard

_✨ linecard 是一个基于 pillow 的一个方便文字转图片的函数。 ✨_

[![Python](https://img.shields.io/badge/Python-3.12+-blue.svg)](https://www.python.org/)
[![pypi](https://img.shields.io/pypi/v/linecard.svg)](https://pypi.python.org/pypi/linecard)
[![pypi download](https://img.shields.io/pypi/dm/linecard)](https://pypi.python.org/pypi/linecard)
[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![LICENSE](https://img.shields.io/github/license/karisaya/linecard.svg)](./LICENSE)

</div>

[使用方法见示例文件](/example/main.py)

![效果](/example/example.png)
